package com.qianhe.service;

import com.qianhe.domain.BzscYsjglggzsc;

import java.util.List;


/**
 * 标准手册-油水井管理岗工作手册-总Service接口
 *
 * @author qianhe
 * @date 2024-10-09
 */
public interface IBzscYsjglggzscService
{
    /**
     * 查询标准手册-油水井管理岗工作手册-总
     *
     * @param ID 标准手册-油水井管理岗工作手册-总主键
     * @return 标准手册-油水井管理岗工作手册-总
     */
    public BzscYsjglggzsc selectBzscYsjglggzscByID(Long ID);

    /**
     * 查询标准手册-油水井管理岗工作手册-总列表
     *
     * @param bzscYsjglggzsc 标准手册-油水井管理岗工作手册-总
     * @return 标准手册-油水井管理岗工作手册-总集合
     */
    public List<BzscYsjglggzsc> selectBzscYsjglggzscList(BzscYsjglggzsc bzscYsjglggzsc);

    /**
     * 新增标准手册-油水井管理岗工作手册-总
     *
     * @param bzscYsjglggzsc 标准手册-油水井管理岗工作手册-总
     * @return 结果
     */
    public int insertBzscYsjglggzsc(BzscYsjglggzsc bzscYsjglggzsc);

    /**
     * 修改标准手册-油水井管理岗工作手册-总
     *
     * @param bzscYsjglggzsc 标准手册-油水井管理岗工作手册-总
     * @return 结果
     */
    public int updateBzscYsjglggzsc(BzscYsjglggzsc bzscYsjglggzsc);

    /**
     * 批量删除标准手册-油水井管理岗工作手册-总
     *
     * @param IDs 需要删除的标准手册-油水井管理岗工作手册-总主键集合
     * @return 结果
     */
    public int deleteBzscYsjglggzscByIDs(Long[] IDs);

    /**
     * 删除标准手册-油水井管理岗工作手册-总信息
     *
     * @param ID 标准手册-油水井管理岗工作手册-总主键
     * @return 结果
     */
    public int deleteBzscYsjglggzscByID(Long ID);
}
